PCB Environment: Rasterizer< ROP > Class Template Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
Rasterizer< ROP > Class Template Reference

## Public Member Functions
| Rasterizer (const UniformGrid25 &G)
void | setExpansion (Real s)
void | rasterizeFill (const Bbox_2 &, uint Z0, uint Z1)
void | rasterizeLine (const Bbox_2 &, uint Z0, uint Z1)
void | rasterizeFill (const Segment_25 &)
void | rasterizeLine (const Segment_25 &)
void | rasterizeFill (const Segment_25 &, uint Z0, uint Z1)
void | rasterizeLine (const Segment_25 &, uint Z0, uint Z1)
void | rasterizeFill (const WideSegment_25 &, uint capsMask=RASTERIZE_CAPS_MASK_BOTH)
void | rasterizeLine (const WideSegment_25 &, uint capsMask=RASTERIZE_CAPS_MASK_BOTH)
void | rasterizeFill (const WideSegment_25 &, uint capsMask, uint Z0, uint Z1)
void | rasterizeLine (const WideSegment_25 &, uint capsMask, uint Z0, uint Z1)
void | rasterizeFill (const Circle_2 &, uint Z0, uint Z1)
void | rasterizeLine (const Circle_2 &, uint Z0, uint Z1)
void | rasterizeFill (const Triangle_2 &, uint Z0, uint Z1)
void | rasterizeLine (const Triangle_2 &, uint Z0, uint Z1)
void | rasterizeFill (const Polygon_2 &, uint Z0, uint Z1)
void | rasterizeLine (const Polygon_2 &, uint Z0, uint Z1)
void | rasterizeFill (const AShape *, uint Z0, uint Z1)
void | rasterizeLine (const AShape *, uint Z0, uint Z1)
void | rasterizeFill (const Track &, uint mask=RASTERIZE_MASK_ALL)
void | rasterizeLine (const Track &)
void | rasterizeRanges (const std::vector< IndexRange > &)

## Data Fields
ROP | OP

The documentation for this class was generated from the following files:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Rasterizer.hpp
- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RasterizerMidpoint.hpp